========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/searchlight.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html
    :alt: Searchlight is an official OpenStack project as indicated by
          the "project:official" badge
.. NOTE(rosmaita): the alt text above will have to be updated when
   additional tags are asserted for Searchlight.  (The SVG in the
   governance repo is updated automatically.)

.. Change things from this point on

========
Welcome!
========

The Searchlight project provides indexing and search capabilities across
OpenStack resources. Its goal is to achieve high performance and flexible
querying combined with near real-time indexing. It uses Elasticsearch, a
real-time distributed indexing and search engine built on Apache Lucene, but
adds OpenStack authentication and Role Based Access Control to provide
appropriate protection of data.

Documentations
==============

* Installation instruction and user guides:
  https://docs.openstack.org/searchlight/latest
* Searchlight wiki:
  https://wiki.openstack.org/wiki/Searchlight
* Release notes: https://docs.openstack.org/releasenotes/searchlight/
* Specs: https://specs.openstack.org/openstack/searchlight-specs/

Code
====

Searchlight code is available in the following repositories:

* Searchlight API and Listener:
  https://opendev.org/openstack/searchlight
* Searchlight Python client:
  https://opendev.org/openstack/python-searchlightclient
* Searchlight Horizon UI:
  https://opendev.org/openstack/searchlight-ui

Bugs
====

Please report bugs at https://storyboard.openstack.org/#!/project_group/searchlight

License
=======

Apache Licence 2.0

Other Resources
===============

Use the following resources to learn more:

* Storyboard project: https://storyboard.openstack.org/#!/project_group/searchlight
* Send mail to openstack-discuss@lists.openstack.org with [Searchlight]
  tag for help and hacking of Searchlight
* IRC channel: #openstack-searchlight
